atomate.lammps.firetasks package — atomate 0.3 documentation

# atomate.lammps.firetasks package

## Submodules

## atomate.lammps.firetasks.parse_outputs module

class `atomate.lammps.firetasks.parse_outputs.` `LammpsToDBTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Enter a LAMMPS run into the database.

  Require params:
    lammps_input (DictLammpsInput)
  Optional params:
    calc_dir (str): path to dir (on current filesystem) that contains LAMMPS
      output files. Default: use current working directory.
    calc_loc (str OR bool): if True will set most recent calc_loc. If str
      search for the most recent calc_loc with the matching name
    diffusion_params (dict): parameters to the diffusion_analyzer. If specified a summary
      of diffusion statistics will be added.
    db_file (str): path to file containing the database credentials.
      Supports env_chk. Default: write data to JSON file.
  `optional_params` = [u'calc_dir', u'calc_loc', u'diffusion_params', u'db_file']
  `required_params` = [u'lammps_input']
  `run_task`(fw_spec)

## atomate.lammps.firetasks.run_calc module

class `atomate.lammps.firetasks.run_calc.` `RunLammpsCustodian`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

class `atomate.lammps.firetasks.run_calc.` `RunLammpsDirect`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Run LAMMPS directly (no custodian).

  Required params:
    lammsps_cmd (str): full command string
  `required_params` = [u'lammps_cmd']
  `run_task`(fw_spec)

class `atomate.lammps.firetasks.run_calc.` `RunPackmol`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Run packmol.

  Required params:

    molecules (list): list of constituent molecules(Molecule objects) packing_config (list): list of dict config settings for each molecule in the

    > molecules list. eg: config settings for a single moelcule [{“number”: 1, “inside box”:[0,0,0,100,100,100]}]

  Optional params:

    tolerance (float): packmol tolerance filetype (string): input/output structure file type control_params: packmol control parameters dictionary. Basically all parameters other

    > than structure/atoms

    output_file: output file name. The extension will be adjusted according to the filetype

  `optional_params` = [u'tolerance', u'filetype', u'control_params', u'output_file']
  `required_params` = [u'molecules', u'packing_config']
  `run_task`(fw_spec)

## atomate.lammps.firetasks.write_inputs module

class `atomate.lammps.firetasks.write_inputs.` `WritelammpsInputFromDictInput`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Writes LAMMPS Input files(data file and the control parameters file) from DictLammpsInput.

  required_params:
    lammps_dict_input (DictLammpsInput) input_file (string): name of the file to which the input params will be written
  optional_params:
    data_file (string): if specified the data file will be renamed
  `optional_params` = [u'data_file']
  `required_params` = [u'lammps_dict_input', u'input_file']
  `run_task`(fw_spec)

## Module contents